@@ -92,9 +92,10 @@ class _CRG(Module):
 
 class BaseSoC(SoCCore):
     def __init__(self, revision="rev0", device="45F", sdram_device="MT41K512M16",
-                 sys_clk_freq  = int(75e6),
-                 with_ethernet = False,
-                 toolchain     = "trellis",
+                 sys_clk_freq    = int(75e6),
+                 with_ethernet   = False,
+                 with_led_chaser = True,
+                 toolchain       = "trellis",
                  **kwargs):
         platform = logicbone.Platform(revision=revision, device=device ,toolchain=toolchain)
 
@@ -142,9 +143,10 @@ class BaseSoC(SoCCore):
 
 
         # Leds -------------------------------------------------------------------------------------
-        self.submodules.leds = LedChaser(
-            pads         = platform.request_all("user_led"),
-            sys_clk_freq = sys_clk_freq)
+        if with_led_chaser:
+            self.submodules.leds = LedChaser(
+                pads         = platform.request_all("user_led"),
+                sys_clk_freq = sys_clk_freq)
 
 # Build --------------------------------------------------------------------------------------------
 
